"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.globalLogger = exports.Logger = exports.BaseLogger = void 0;
const pino_1 = __importDefault(require("pino"));
const isDebugEnabled = () => process.env.LOG_LEVEL === 'debug';
class BaseLogger {
    constructor(meta = {}) {
        this.meta = meta;
        this.logger = (0, pino_1.default)({
            level: process.env.LOG_LEVEL || 'info',
            formatters: { level: (level) => ({ level }) },
            base: null,
            mixin: () => meta,
        });
    }
    child(meta = {}) {
        return new BaseLogger({ ...this.meta, ...meta });
    }
    info(message, args) {
        this.logger.info(args, message);
    }
    error(message, args) {
        this.logger.error(args, message);
    }
    debug(message, args) {
        this.logger.debug(args, message);
    }
    warn(message, args) {
        this.logger.warn(args, message);
    }
    log(args) {
        this.logger.info(args);
    }
}
exports.BaseLogger = BaseLogger;
class Logger extends BaseLogger {
    constructor(traceId, flows, step, socketServer) {
        super({ traceId, flows, step });
        this.traceId = traceId;
        this.flows = flows;
        this.step = step;
        this.socketServer = socketServer;
        this.info = (message, args) => {
            super.info(message, args);
            this.emitLog('info', message, args);
        };
        this.error = (message, args) => {
            super.error(message, args);
            this.emitLog('error', message, args);
        };
        this.debug = (message, args) => {
            super.debug(message, args);
            if (isDebugEnabled()) {
                this.emitLog('debug', message, args);
            }
        };
        this.warn = (message, args) => {
            super.warn(message, args);
            this.emitLog('warn', message, args);
        };
        this.emitLog = (level, msg, args) => {
            socketServer?.emit('log', {
                step: this.step,
                ...(args ?? {}),
                level,
                time: Date.now(),
                msg,
                traceId: this.traceId,
                flows: this.flows,
            });
        };
    }
    child(meta = {}) {
        return new Logger(this.traceId, this.flows, meta.step, this.socketServer);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    log(message) {
        console.log(JSON.stringify(message));
        this.emitLog(message.level, message.msg, message);
    }
}
exports.Logger = Logger;
exports.globalLogger = new BaseLogger();
